@@ -21,6 +21,7 @@ import logging
 import os
 import stat
 import sys
+from requests import ConnectionError
 import tempfile
 import traceback
 from . import __version__
@@ -97,7 +98,7 @@ class Config(dict):
     def __del__(self):
         json.dump(self,self.f)
         self.f.close()
-    
+
     def get_client(self):
         if not (self.mfn_url and self.mfn_user and self.mfn_password):
             print("Please login")
@@ -135,9 +136,12 @@ def version(config):
     print("mfn_cli "+__version__)
     from mfn_sdk import __version__ as sdkversion
     print("mfn_sdk "+sdkversion)
-    client = config.get_client()
     try:
+        client = config.get_client()
         print("management service "+client.version())
+    except ConnectionError as e:
+        print("can't connect to management service")
+        log.error(e)
     except Exception as e:
         log.error(e)
 
@@ -161,7 +165,7 @@ def login(config, url=None, user=None, name=None, password=None):
             url = 'http://'+url
 
     # overwrite values if provided
-    config.mfn_url = url or config.mfn_url or default.get('mfn_url', 'https://knix.io/mfn')
+    config.mfn_url = url or config.mfn_url or default.get('mfn_url', 'https://knix.io')
     config.mfn_user = user or config.mfn_user or default.get('mfn_user')
     config.mfn_name = name or config.mfn_name or default.get('mfn_name')
     config.mfn_password = password or config.mfn_password or default.get('mfn_password')
@@ -172,14 +176,14 @@ def login(config, url=None, user=None, name=None, password=None):
     config.proxies = default.get('proxies', None)
     if config.proxies is None:
         proxies=dict()
-        if 'http_proxy' in sys.environ:
-            config.proxies['http'] = sys.environ['http_proxy']
-        elif 'HTTP_PROXY' in sys.environ:
-            config.proxies['http'] = sys.environ['HTTP_PROXY']
-        if 'https_proxy' in sys.environ:
-            config.proxies['https'] = sys.environ['https_proxy']
-        elif 'HTTPS_PROXY' in sys.environ:
-            config.proxies['https'] = sys.environ['HTTPS_PROXY']
+        if 'http_proxy' in os.environ:
+            config.proxies['http'] = os.environ['http_proxy']
+        elif 'HTTP_PROXY' in os.environ:
+            config.proxies['http'] = os.environ['HTTP_PROXY']
+        if 'https_proxy' in os.environ:
+            config.proxies['https'] = os.environ['https_proxy']
+        elif 'HTTPS_PROXY' in os.environ:
+            config.proxies['https'] = os.environ['HTTPS_PROXY']
         if len(proxies) > 0:
             config.proxies = proxies
     try:
@@ -197,7 +201,7 @@ def login(config, url=None, user=None, name=None, password=None):
 @pass_config
 def invoke(config, workflow, data=None):
     """Invoke a workflow.
-    
+
     DATA can be any string
     """
     client = config.get_client()
@@ -231,7 +235,7 @@ def deploy(config, workflow=None, timeout=None):
 @pass_config
 def undeploy(config, workflow=None, timeout=None):
     """Undeploy a workflow.
-    
+
     """
     client = config.get_client()
     try:
@@ -289,7 +293,7 @@ def create(ctx):
 @pass_config
 def create_workflow(config,name,file):
     """ Create a workflow
-    
+
     NAME is the workflow's name, an ID will be generated by the platform
     """
     if file:
@@ -302,11 +306,11 @@ def create_workflow(config,name,file):
     client = config.get_client()
     wf = client.add_workflow(str(name).strip())
     log.info("Created workflow "+wf._name+" ("+wf.id+")")
-    if wfd:
+    if file and wfd:
         wf.json = wfd
     click.echo(wf.id)
 
-# The new choice class allows a dictionary of choices and in case it is asked for all alternatives, it 
+# The new choice class allows a dictionary of choices and in case it is asked for all alternatives, it
 class MyChoice(click.Choice):
     def __init__(self, choices, default=None, *args, **kwargs):
         self.aliases = choices
@@ -337,7 +341,7 @@ runtimes = {
 @pass_config
 def create_function(config,runtime,name,file):
     """Create a function.
-    
+
     NAME is the function's name, an ID will be generated by the platform
     """
     if file:
@@ -351,7 +355,7 @@ def create_function(config,runtime,name,file):
     client = config.get_client()
     fn = client.add_function(str(name).strip(),runtime)
     log.info("Created function "+fn._name+" ("+fn.id+")")
-    if code:
+    if file and code:
         fn.code = code
     click.echo(fn.id)
 
@@ -371,7 +375,7 @@ def get(ctx):
 @pass_config
 def get_workflow(config,workflow):
     """Get workflow.
-    
+
     WORKFLOW can be the workflow's name or ID, accepts partial values
     """
     client = config.get_client()
@@ -415,7 +419,7 @@ def get_function(config,function):
         rtlen = max(rtlen,len(g._runtime))
     formatstr = f"%-32s %-{namelen}s %-{rtlen}s %-12s"
     for row in table:
-        click.echo(formatstr % row)    
+        click.echo(formatstr % row)
 
 
 ##########
@@ -450,7 +454,7 @@ def edit(ctx):
 @pass_config
 def edit_workflow(config,workflow):
     """Edit workflow description.
-    
+
     WORKFLOW can be the workflow's name or ID, accepts partial values
     """
     client = config.get_client()
@@ -509,7 +513,7 @@ def delete(ctx,force):
 @click.pass_context
 def delete_workflow(ctx,name,force):
     """Delete a workflow
-    
+
     WORKFLOW can be the workflow's name or ID, accepts partial values
     """
     ctx.obj.force=force
@@ -560,7 +564,7 @@ def workflow(config, workflow):
 @pass_config
 def workflows(config):
     """List workflows.
-    
+
     WORKFLOW can be the workflow's name or ID, accepts partial values
     """
     client = config.get_client()
@@ -603,7 +607,7 @@ def function(config, function="", subcommand=None):
 @pass_config
 def functions(config):
     """List functions.
-    
+
     FUNCTION can be the function's name or ID, accepts partial values
     """
     client = config.get_client()
